
# Type: double


A real number that conforms to the xsd:double specification

URI: [https://w3id.org/biolink/biolinkml/meta/biolinkml:types/Double](https://w3id.org/biolink/biolinkml/meta/biolinkml:types/Double)

|  |  |  |
| --- | --- | --- |
| Root (builtin) type | | **float** |
